#!/bin/sh
# installation script for conv_subs script v0.1 (dec 15, 2007)
#
# description:
# conv_subs for gp2x will allow you to convert
# text subtitles from cp1250 (win-1250) encoding
# (used e. g. for slovak/czech subtitles) into
# utf-8 encoded subtitles which gp2x movie player
# can properly display
#
# prerequisites:
#  * perl - minimal installation (http://archive.gp2x.de/cgi-bin/cfiles.cgi?0,0,0,0,14,1155)
#  * sterm (http://archive.gp2x.de/cgi-bin/cfiles.cgi?0,0,0,0,8,1893)
#
# installation:
#  * run this shell script from sterm and it should be all done
#
# usage:
# run sterm, navigate to directory where subtitles
# are located and run
# conv_subs subtitle_file
#
# the result is subtitle_file-utf8. rename this
# file so that it shares the movie name except
# for the file extension, exit sterm and play
# it in media player
#
# example session:
# menu -> sterm
# cd /mnt/sd/movies/gp2xdemo
# ls
#  movie.avi subtitles.sub
# conv_subs subtitles.sub
#  (will take a while)
# mv subtitles.sub-utf8 movie.sub
# exit
# play movie
#
#
#            december 2007, jose 1711 gmail com
#
[ -f /usr/bin/conv_subs ] && { echo "Script seems already to be installed. Exiting..."; exit 1; }

cat >/usr/bin/conv_subs << EOF
#!/usr/bin/perl
# conv_subs                            v.0.1
#                                  december 2007
# 
# This perl script written for GP2x will convert
# your text subtitles from cp1250 (win-1250) en-
# coding to utf-8, so that movie player may dis-
# play them properly
# 
# usage:
#  * run conv_subs subtitle_to_convert from sterm
#  * rename the resulting file according to the
#    movie filename
#
#                          jose1711 gmail dot com
#                    comments/fixes/ideas welcome
#
use Encode;

if (\$#ARGV != 0) { print "I need exactly one argument - subtitle file\n"; exit 1 };

if (-s "@ARGV[0]" > 200000){
	print "This file is too big (>200 kB).\nMaybe it is not a subtitle file?\n";
	die;
}

open INPUT, "<@ARGV[0]" or die("Subtitle file could not be opened");
open OUTPUT, ">@ARGV[0]-utf8" or die("I cannot write here");

binmode INPUT;
binmode OUTPUT;

print "Converting from cp1250 to utf-8..\n";

while (<INPUT>) {
print OUTPUT encode("utf-8",decode("cp1250",\$_));	
}

print "Done\n";

# I am getting relocation error here so I comment
# this out. Maybe it will work for you. Dunno.
#@all_files = glob("*");
#foreach (@all_files) {
#	if (\$_=~ /[aA][vV][iI]\$|[mM][pP][gG]\$/) {
#		@possibly_movie_files=(@possibly_movie_files,\$_);
#	}
#}

#if (\$#possibly_movie_files == 0){
#	\$renamed_sub_file=\$possibly_movie_files[0];
#	\$renamed_sub_file =~ s/\.[^.]*\$//;
#	\$renamed_sub_file .= ".sub";
#	print "Now you need to rename the subtitle file..\n";
#	print "Perhaps with mv @ARGV[0]-utf-8 \$renamed_sub_file\n";
#	}

close INPUT;
close OUPUT;

exit 0
EOF

chmod 777 /usr/bin/conv_subs && echo "Successfully installed"
exit 0
